@@ -74,17 +74,18 @@ route <- function(from = NULL, to = NULL, l = NULL,
 #' @family routes
 #' @export
 #' @examples
-#' # from <- matrix(stplanr::geo_code("pedallers arms leeds"), ncol = 2)
-#' from <- matrix(c(-1.5327711, 53.8006988), ncol = 2)
-#' # to <- matrix(stplanr::geo_code("gzing"), ncol = 2)
-#' to <- matrix(c(-1.527937, 53.8044309), ncol = 2)
-#' pts <- rbind(from, to)
-#' colnames(pts) = c("X", "Y")
-#' # net <- dodgr::dodgr_streetnet(pts = pts, expand = 0.1)
+#' # from <- geo_code("pedallers arms leeds")
+#' from <- c(-1.5327, 53.8006)
+#' # to <- geo_code("gzing")
+#' to <- c(-1.5279, 53.8044)
+#' # next 4 lines recreate `stplanr::osm_net_example`
+#' # pts <- rbind(from, to)
+#' # colnames(pts) <- c("X", "Y")
+#' # net <- dodgr::dodgr_streetnet(pts = rbind(from, to), expand = 0.1)
 #' # osm_net_example <- net[c("highway", "name", "lanes", "maxspeed")]
 #' r <- route_dodgr(from, to, net = osm_net_example)
 #' plot(osm_net_example$geometry)
-#' plot(r, add = TRUE, col = "red", lwd = 5)
+#' plot(r$geometry, add = TRUE, col = "red", lwd = 5)
 route_dodgr <-
   function(from = NULL,
            to = NULL,
@@ -92,17 +93,15 @@ route_dodgr <-
            net = NULL
            # ,
            # return_net = FALSE
-
            ) {
 
-  if(is.numeric(from) & is.numeric(to)) {
-    from_coords <- from
-    to_coords <- to
-  }
+  od_coordinate_matrix <- od_coords(from, to)
+  fm_coords <- od_coordinate_matrix[, 1:2, drop = FALSE]
+  to_coords <- od_coordinate_matrix[, 3:4, drop = FALSE]
 
   # Try to get route network if net not provided
   if(is.null(net)) {
-      pts <- rbind(from_coords, to_coords)
+      pts <- rbind(fm_coords, to_coords)
       net <- dodgr::dodgr_streetnet(pts = pts, expand = 0.2)
   }
 
@@ -112,7 +111,7 @@ route_dodgr <-
 
   verts <- dodgr::dodgr_vertices(ways_dg) # the vertices or points for routing
   #suppressMessages ({
-    from_id <- verts$id[dodgr::match_pts_to_graph(verts, from_coords)]
+    from_id <- verts$id[dodgr::match_pts_to_graph(verts, fm_coords)]
     to_id <- verts$id[dodgr::match_pts_to_graph(verts, to_coords)]
   #})
   dp <- dodgr::dodgr_paths(ways_dg, from = from_id, to = to_id)
@@ -123,8 +122,8 @@ route_dodgr <-
     }))
   nms <- unlist(lapply(paths, function (i) names (i)))
   from_to <- do.call(rbind, strsplit(nms, "-"))
-  from_xy <- from_coords[match(from_to[, 1], unique(from_to[, 1])), , drop = FALSE]
-  to_xy <- from_coords[match(from_to[, 2], unique(from_to[, 2])), , drop = FALSE]
+  from_xy <- fm_coords[match(from_to[, 1], unique(from_to[, 1])), , drop = FALSE]
+  to_xy <- fm_coords[match(from_to[, 2], unique(from_to[, 2])), , drop = FALSE]
 
   paths <- sf::st_sfc(unlist(paths, recursive = FALSE), crs = 4326)
   sf::st_sf(from = from_to[, 1],
